********************
Kalman Filters
********************

.. automodule:: pymc_extras.statespace.filters
.. autosummary::
   :toctree: generated

    StandardFilter
    UnivariateFilter
    KalmanSmoother
    SquareRootFilter
    LinearGaussianStateSpace
